@@ -49,6 +49,8 @@ struct _GthImagePrintJobClass {
 
 GType              gth_image_print_job_get_type (void);
 GthImagePrintJob * gth_image_print_job_new      (GList                    *file_data_list,
+						 GthFileData              *current,
+						 GdkPixbuf                *current_image,
 						 GError                  **error);
 void               gth_image_print_job_run      (GthImagePrintJob         *self,
 						 GtkPrintOperationAction   action,
