@@ -39,12 +39,14 @@ struct _GthImageViewerPagePrivate {
 	guint              merge_id;
 	GthImageHistory   *history;
 	GthFileData       *file_data;
-	gulong             preloader_sig_id;
+	gulong             requested_ready_id;
+	gulong             original_size_ready_id;
 	guint              cnxn_id[GCONF_NOTIFICATIONS];
 	guint              hide_mouse_timeout;
 	guint              motion_signal;
 	gboolean           pixbuf_changed;
 	gboolean           shrink_wrap;
+	GFile             *last_loaded;
 };
 
 static gpointer gth_image_viewer_page_parent_class = NULL;
@@ -203,17 +205,18 @@ static GtkToggleActionEntry image_viewer_toggle_action_entries[] = {
 
 
 static void
-viewer_image_ready_cb (GtkWidget          *widget,
-		       GthImageViewerPage *self)
+gth_image_viewer_page_file_loaded (GthImageViewerPage *self,
+				   gboolean            success)
 {
-	if (self->priv->shrink_wrap)
-		gth_image_viewer_page_shrink_wrap (self, TRUE);
+	if (_g_file_equal (self->priv->last_loaded, self->priv->file_data->file))
+		return;
 
-	gth_image_history_clear (self->priv->history);
-	gth_image_history_add_image (self->priv->history,
-				     gth_image_viewer_get_current_pixbuf (GTH_IMAGE_VIEWER (self->priv->viewer)),
-				     FALSE);
-	gth_viewer_page_file_loaded (GTH_VIEWER_PAGE (self), TRUE);
+	_g_object_unref (self->priv->last_loaded);
+	self->priv->last_loaded = g_object_ref (self->priv->file_data->file);
+
+	gth_viewer_page_file_loaded (GTH_VIEWER_PAGE (self),
+				     self->priv->file_data,
+				     success);
 }
 
 
@@ -284,25 +287,59 @@ viewer_key_press_cb (GtkWidget          *widget,
 
 static void
 image_preloader_requested_ready_cb (GthImagePreloader  *preloader,
+				    GthFileData        *requested,
+				    GdkPixbufAnimation *animation,
+				    int                 original_width,
+				    int                 original_height,
 				    GError             *error,
 				    GthImageViewerPage *self)
 {
-	GthImageLoader *image_loader;
+	if (! _g_file_equal (requested->file, self->priv->file_data->file))
+		return;
 
 	if (error != NULL) {
-		gth_viewer_page_file_loaded (GTH_VIEWER_PAGE (self), FALSE);
-		return;
-	}
-
-	image_loader = gth_image_preloader_get_loader (self->priv->preloader, gth_image_preloader_get_requested (self->priv->preloader));
-	if (image_loader == NULL) {
-		gth_viewer_page_file_loaded (GTH_VIEWER_PAGE (self), FALSE);
+		gth_image_viewer_page_file_loaded (self, FALSE);
 		return;
 	}
 
 	gth_viewer_page_focus (GTH_VIEWER_PAGE (self));
+	gth_image_viewer_set_animation (GTH_IMAGE_VIEWER (self->priv->viewer),
+					animation,
+					original_width,
+					original_height);
+	if (self->priv->shrink_wrap)
+		gth_image_viewer_page_shrink_wrap (self, TRUE);
+	gth_image_history_clear (self->priv->history);
+	gth_image_history_add_image (self->priv->history,
+				     gth_image_viewer_get_current_pixbuf (GTH_IMAGE_VIEWER (self->priv->viewer)),
+				     FALSE);
+	gth_image_viewer_page_file_loaded (self, TRUE);
+}
 
-	gth_image_viewer_load_from_image_loader (GTH_IMAGE_VIEWER (self->priv->viewer), image_loader);
+
+static void
+image_preloader_original_size_ready_cb (GthImagePreloader  *preloader,
+				        GthFileData        *requested,
+				        GdkPixbufAnimation *animation,
+				        int                 original_width,
+				        int                 original_height,
+				        GError             *error,
+				        GthImageViewerPage *self)
+{
+	if (! _g_file_equal (requested->file, self->priv->file_data->file))
+		return;
+
+	if (error != NULL)
+		return;
+
+	gth_image_viewer_set_better_quality (GTH_IMAGE_VIEWER (self->priv->viewer),
+					     animation,
+					     original_width,
+					     original_height);
+	gth_image_history_clear (self->priv->history);
+	gth_image_history_add_image (self->priv->history,
+				     gth_image_viewer_get_current_pixbuf (GTH_IMAGE_VIEWER (self->priv->viewer)),
+				     FALSE);
 }
 
 
@@ -439,10 +476,14 @@ gth_image_viewer_page_real_activate (GthViewerPage *base,
 	gtk_ui_manager_insert_action_group (gth_browser_get_ui_manager (browser), self->priv->actions, 0);
 
 	self->priv->preloader = gth_browser_get_image_preloader (browser);
-	self->priv->preloader_sig_id = g_signal_connect (G_OBJECT (self->priv->preloader),
-							 "requested_ready",
-							 G_CALLBACK (image_preloader_requested_ready_cb),
-							 self);
+	self->priv->requested_ready_id = g_signal_connect (G_OBJECT (self->priv->preloader),
+							   "requested_ready",
+							   G_CALLBACK (image_preloader_requested_ready_cb),
+							   self);
+	self->priv->original_size_ready_id = g_signal_connect (G_OBJECT (self->priv->preloader),
+							       "original_size_ready",
+							       G_CALLBACK (image_preloader_original_size_ready_cb),
+							       self);
 
 	self->priv->viewer = gth_image_viewer_new ();
 	gth_image_viewer_set_zoom_quality (GTH_IMAGE_VIEWER (self->priv->viewer), eel_gconf_get_enum (PREF_ZOOM_QUALITY, GTH_TYPE_ZOOM_QUALITY, GTH_ZOOM_QUALITY_HIGH));
@@ -460,10 +501,6 @@ gth_image_viewer_page_real_activate (GthViewerPage *base,
 
 	gtk_widget_show (self->priv->viewer);
 
-	g_signal_connect (G_OBJECT (self->priv->viewer),
-			  "image_ready",
-			  G_CALLBACK (viewer_image_ready_cb),
-			  self);
 	g_signal_connect (G_OBJECT (self->priv->viewer),
 			  "zoom_changed",
 			  G_CALLBACK (viewer_zoom_changed_cb),
@@ -563,8 +600,10 @@ gth_image_viewer_page_real_deactivate (GthViewerPage *base)
 	g_object_unref (self->priv->actions);
 	self->priv->actions = NULL;
 
-	g_signal_handler_disconnect (self->priv->preloader, self->priv->preloader_sig_id);
-	self->priv->preloader_sig_id = 0;
+	g_signal_handler_disconnect (self->priv->preloader, self->priv->requested_ready_id);
+	g_signal_handler_disconnect (self->priv->preloader, self->priv->original_size_ready_id);
+	self->priv->requested_ready_id = 0;
+	self->priv->original_size_ready_id = 0;
 
 	g_object_unref (self->priv->preloader);
 	self->priv->preloader = NULL;
@@ -629,19 +668,24 @@ gth_image_viewer_page_real_view (GthViewerPage *base,
 	GthFileStore       *file_store;
 	GtkTreeIter         iter;
 	GthFileData        *next_file_data = NULL;
+	GthFileData        *next2_file_data = NULL;
 	GthFileData        *prev_file_data = NULL;
+	int                 window_width;
+	int                 window_height;
 
 	self = (GthImageViewerPage*) base;
 	g_return_if_fail (file_data != NULL);
 
 	gth_viewer_page_focus (GTH_VIEWER_PAGE (self));
 
+	_g_clear_object (&self->priv->last_loaded);
+
 	if ((self->priv->file_data != NULL)
 	    && g_file_equal (file_data->file, self->priv->file_data->file)
 	    && (gth_file_data_get_mtime (file_data) == gth_file_data_get_mtime (self->priv->file_data))
 	    && ! self->priv->pixbuf_changed)
 	{
-		gth_viewer_page_file_loaded (GTH_VIEWER_PAGE (self), TRUE);
+		gth_image_viewer_page_file_loaded (self, TRUE);
 		return;
 	}
 
@@ -649,22 +693,34 @@ gth_image_viewer_page_real_view (GthViewerPage *base,
 	self->priv->file_data = gth_file_data_dup (file_data);
 
 	file_store = gth_browser_get_file_store (self->priv->browser);
-	if (gth_file_store_find_visible (file_store, file_data->file, &iter)) {
+	if (gth_file_store_find_visible (file_store, self->priv->file_data->file, &iter)) {
 		GtkTreeIter iter2;
+		GtkTreeIter iter3;
 
 		iter2 = iter;
 		if (gth_file_store_get_next_visible (file_store, &iter2))
 			next_file_data = gth_file_store_get_file (file_store, &iter2);
 
+		iter3 = iter2;
+		if (gth_file_store_get_next_visible (file_store, &iter3))
+			next2_file_data = gth_file_store_get_file (file_store, &iter3);
+
 		iter2 = iter;
 		if (gth_file_store_get_prev_visible (file_store, &iter2))
 			prev_file_data = gth_file_store_get_file (file_store, &iter2);
 	}
 
+	gtk_window_get_size (GTK_WINDOW (self->priv->browser),
+			     &window_width,
+			     &window_height);
+
 	gth_image_preloader_load (self->priv->preloader,
-				  file_data,
+				  self->priv->file_data,
+				  (gth_image_prelaoder_get_load_policy (self->priv->preloader) == GTH_LOAD_POLICY_TWO_STEPS) ? MAX (window_width, window_height) : -1,
 				  next_file_data,
-				  prev_file_data);
+				  next2_file_data,
+				  prev_file_data,
+				  NULL);
 }
 
 
@@ -964,7 +1020,7 @@ _gth_image_viewer_page_set_pixbuf (GthImageViewerPage *self,
 	int          height;
 	char        *size;
 
-	gth_image_viewer_set_pixbuf (GTH_IMAGE_VIEWER (self->priv->viewer), pixbuf);
+	gth_image_viewer_set_pixbuf (GTH_IMAGE_VIEWER (self->priv->viewer), pixbuf, -1, -1);
 
 	file_data = gth_browser_get_current_file (GTH_BROWSER (self->priv->browser));
 
@@ -1007,6 +1063,7 @@ gth_image_viewer_page_finalize (GObject *obj)
 
 	g_object_unref (self->priv->history);
 	_g_object_unref (self->priv->file_data);
+	_g_object_unref (self->priv->last_loaded);
 
 	G_OBJECT_CLASS (gth_image_viewer_page_parent_class)->finalize (obj);
 }
@@ -1048,6 +1105,7 @@ gth_image_viewer_page_instance_init (GthImageViewerPage *self)
 	self->priv = GTH_IMAGE_VIEWER_PAGE_GET_PRIVATE (self);
 	self->priv->history = gth_image_history_new ();
 	self->priv->shrink_wrap = FALSE;
+	self->priv->last_loaded = NULL;
 }
 
 
@@ -1185,15 +1243,15 @@ void
 gth_image_viewer_page_shrink_wrap (GthImageViewerPage *self,
 				   gboolean            activate)
 {
-	GdkPixbuf *pixbuf;
-	int        width;
-	int        height;
-	double     ratio;
-	int        other_width;
-	int        other_height;
-	GdkScreen *screen;
-	int        max_width;
-	int        max_height;
+	GthFileData *file_data;
+	int          width;
+	int          height;
+	double       ratio;
+	int          other_width;
+	int          other_height;
+	GdkScreen   *screen;
+	int          max_width;
+	int          max_height;
 
 	self->priv->shrink_wrap = activate;
 	if (! self->priv->shrink_wrap) {
@@ -1215,12 +1273,14 @@ gth_image_viewer_page_shrink_wrap (GthImageViewerPage *self,
 		return;
 	}
 
-	pixbuf = gth_image_viewer_page_get_pixbuf (self);
-	if (pixbuf == NULL)
+	file_data = gth_browser_get_current_file (self->priv->browser);
+	if (file_data == NULL)
+		return;
+
+	gth_image_viewer_get_original_size (GTH_IMAGE_VIEWER (self->priv->viewer), &width, &height);
+	if ((width <= 0) || (height <= 0))
 		return;
 
-	width = gdk_pixbuf_get_width (pixbuf);
-	height = gdk_pixbuf_get_height (pixbuf);
 	ratio = (double) width / height;
 
 	other_width = 0;
