@@ -76,7 +76,7 @@
 /* Copy the first part of user declarations.  */
 
 /* Line 189 of yacc.c  */
-#line 1 "../../../extensions/webalbums/albumtheme.y"
+#line 1 "albumtheme.y"
 
 /*
  *  GThumb
@@ -94,7 +94,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
 
 #include <string.h>
@@ -169,7 +170,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 37 "../../../extensions/webalbums/albumtheme.y"
+#line 37 "albumtheme.y"
 
 	char         *text;
 	int           ivalue;
@@ -1495,7 +1496,7 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 77 "../../../extensions/webalbums/albumtheme.y"
+#line 77 "albumtheme.y"
     {
 			yy_parsed_doc = (yyvsp[(1) - (1)].list);
 			if (yy_parsed_doc == NULL)
@@ -1508,7 +1509,7 @@ yyreduce:
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 86 "../../../extensions/webalbums/albumtheme.y"
+#line 86 "albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), gth_tag_new_html ((yyvsp[(1) - (2)].text)));
 			g_free ((yyvsp[(1) - (2)].text));
@@ -1518,7 +1519,7 @@ yyreduce:
   case 4:
 
 /* Line 1455 of yacc.c  */
-#line 91 "../../../extensions/webalbums/albumtheme.y"
+#line 91 "albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		;}
@@ -1527,7 +1528,7 @@ yyreduce:
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 95 "../../../extensions/webalbums/albumtheme.y"
+#line 95 "albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		;}
@@ -1536,7 +1537,7 @@ yyreduce:
   case 6:
 
 /* Line 1455 of yacc.c  */
-#line 99 "../../../extensions/webalbums/albumtheme.y"
+#line 99 "albumtheme.y"
     {
 			GthTag *tag;
 
@@ -1549,7 +1550,7 @@ yyreduce:
   case 7:
 
 /* Line 1455 of yacc.c  */
-#line 107 "../../../extensions/webalbums/albumtheme.y"
+#line 107 "albumtheme.y"
     {
 			GList  *cond_list;
 			GthTag *tag;
@@ -1567,7 +1568,7 @@ yyreduce:
   case 8:
 
 /* Line 1455 of yacc.c  */
-#line 120 "../../../extensions/webalbums/albumtheme.y"
+#line 120 "albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1576,7 +1577,7 @@ yyreduce:
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 124 "../../../extensions/webalbums/albumtheme.y"
+#line 124 "albumtheme.y"
     {
 			/*if ($2 != NULL)
 				gth_parsed_doc_free ($2);*/
@@ -1587,7 +1588,7 @@ yyreduce:
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 131 "../../../extensions/webalbums/albumtheme.y"
+#line 131 "albumtheme.y"
     {
 			if (g_str_equal ((yyvsp[(2) - (3)].text), "thumbnail_caption")) {
 				(yyval.loop) = gth_loop_new (GTH_TAG_FOR_EACH_THUMBNAIL_CAPTION);
@@ -1605,7 +1606,7 @@ yyreduce:
   case 11:
 
 /* Line 1455 of yacc.c  */
-#line 144 "../../../extensions/webalbums/albumtheme.y"
+#line 144 "albumtheme.y"
     {
 			(yyval.loop) = gth_range_loop_new ();
 			gth_range_loop_set_range (GTH_RANGE_LOOP ((yyval.loop)), (yyvsp[(2) - (7)].text), (yyvsp[(4) - (7)].expr), (yyvsp[(6) - (7)].expr));
@@ -1619,7 +1620,7 @@ yyreduce:
   case 12:
 
 /* Line 1455 of yacc.c  */
-#line 154 "../../../extensions/webalbums/albumtheme.y"
+#line 154 "albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		;}
@@ -1628,7 +1629,7 @@ yyreduce:
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 158 "../../../extensions/webalbums/albumtheme.y"
+#line 158 "albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		;}
@@ -1637,7 +1638,7 @@ yyreduce:
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 163 "../../../extensions/webalbums/albumtheme.y"
+#line 163 "albumtheme.y"
     {
 			gth_condition_add_document ((yyvsp[(1) - (3)].cond), (yyvsp[(2) - (3)].list));
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].cond));
@@ -1647,7 +1648,7 @@ yyreduce:
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 168 "../../../extensions/webalbums/albumtheme.y"
+#line 168 "albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1656,7 +1657,7 @@ yyreduce:
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 173 "../../../extensions/webalbums/albumtheme.y"
+#line 173 "albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		;}
@@ -1665,7 +1666,7 @@ yyreduce:
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 177 "../../../extensions/webalbums/albumtheme.y"
+#line 177 "albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		;}
@@ -1674,7 +1675,7 @@ yyreduce:
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 182 "../../../extensions/webalbums/albumtheme.y"
+#line 182 "albumtheme.y"
     {
 			GthExpr      *else_expr;
 			GthCondition *cond;
@@ -1691,7 +1692,7 @@ yyreduce:
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 194 "../../../extensions/webalbums/albumtheme.y"
+#line 194 "albumtheme.y"
     {
 			(yyval.cond) = NULL;
 		;}
@@ -1700,7 +1701,7 @@ yyreduce:
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 205 "../../../extensions/webalbums/albumtheme.y"
+#line 205 "albumtheme.y"
     {
 			(yyval.tag) = gth_tag_new (GTH_TAG_SET_VAR, (yyvsp[(2) - (3)].list));
 		;}
@@ -1709,7 +1710,7 @@ yyreduce:
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 210 "../../../extensions/webalbums/albumtheme.y"
+#line 210 "albumtheme.y"
     {
 			if (gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text)) == GTH_TAG_EVAL) {
 				GthExpr *e;
@@ -1762,7 +1763,7 @@ yyreduce:
   case 24:
 
 /* Line 1455 of yacc.c  */
-#line 258 "../../../extensions/webalbums/albumtheme.y"
+#line 258 "albumtheme.y"
     {
 			GthTagType tag_type = gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text));
 			if (tag_type == GTH_TAG_INVALID) {
@@ -1776,7 +1777,7 @@ yyreduce:
   case 25:
 
 /* Line 1455 of yacc.c  */
-#line 268 "../../../extensions/webalbums/albumtheme.y"
+#line 268 "albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].attribute));
 		;}
@@ -1785,7 +1786,7 @@ yyreduce:
   case 26:
 
 /* Line 1455 of yacc.c  */
-#line 272 "../../../extensions/webalbums/albumtheme.y"
+#line 272 "albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1794,7 +1795,7 @@ yyreduce:
   case 27:
 
 /* Line 1455 of yacc.c  */
-#line 277 "../../../extensions/webalbums/albumtheme.y"
+#line 277 "albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_expression ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].expr));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1804,7 +1805,7 @@ yyreduce:
   case 28:
 
 /* Line 1455 of yacc.c  */
-#line 282 "../../../extensions/webalbums/albumtheme.y"
+#line 282 "albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_string ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].text));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1815,7 +1816,7 @@ yyreduce:
   case 29:
 
 /* Line 1455 of yacc.c  */
-#line 288 "../../../extensions/webalbums/albumtheme.y"
+#line 288 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, 1);
@@ -1827,7 +1828,7 @@ yyreduce:
   case 30:
 
 /* Line 1455 of yacc.c  */
-#line 296 "../../../extensions/webalbums/albumtheme.y"
+#line 296 "albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].expr));
 		;}
@@ -1836,7 +1837,7 @@ yyreduce:
   case 31:
 
 /* Line 1455 of yacc.c  */
-#line 300 "../../../extensions/webalbums/albumtheme.y"
+#line 300 "albumtheme.y"
     {
 			(yyval.list) = g_list_prepend (NULL, (yyvsp[(1) - (1)].expr));
 		;}
@@ -1845,7 +1846,7 @@ yyreduce:
   case 32:
 
 /* Line 1455 of yacc.c  */
-#line 304 "../../../extensions/webalbums/albumtheme.y"
+#line 304 "albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1854,7 +1855,7 @@ yyreduce:
   case 33:
 
 /* Line 1455 of yacc.c  */
-#line 309 "../../../extensions/webalbums/albumtheme.y"
+#line 309 "albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (3)].expr);
 		;}
@@ -1863,7 +1864,7 @@ yyreduce:
   case 34:
 
 /* Line 1455 of yacc.c  */
-#line 313 "../../../extensions/webalbums/albumtheme.y"
+#line 313 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1881,7 +1882,7 @@ yyreduce:
   case 35:
 
 /* Line 1455 of yacc.c  */
-#line 326 "../../../extensions/webalbums/albumtheme.y"
+#line 326 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1899,7 +1900,7 @@ yyreduce:
   case 36:
 
 /* Line 1455 of yacc.c  */
-#line 339 "../../../extensions/webalbums/albumtheme.y"
+#line 339 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1917,7 +1918,7 @@ yyreduce:
   case 37:
 
 /* Line 1455 of yacc.c  */
-#line 352 "../../../extensions/webalbums/albumtheme.y"
+#line 352 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1935,7 +1936,7 @@ yyreduce:
   case 38:
 
 /* Line 1455 of yacc.c  */
-#line 365 "../../../extensions/webalbums/albumtheme.y"
+#line 365 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1953,7 +1954,7 @@ yyreduce:
   case 39:
 
 /* Line 1455 of yacc.c  */
-#line 378 "../../../extensions/webalbums/albumtheme.y"
+#line 378 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1971,7 +1972,7 @@ yyreduce:
   case 40:
 
 /* Line 1455 of yacc.c  */
-#line 391 "../../../extensions/webalbums/albumtheme.y"
+#line 391 "albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
 		;}
@@ -1980,7 +1981,7 @@ yyreduce:
   case 41:
 
 /* Line 1455 of yacc.c  */
-#line 395 "../../../extensions/webalbums/albumtheme.y"
+#line 395 "albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NEG);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -1990,7 +1991,7 @@ yyreduce:
   case 42:
 
 /* Line 1455 of yacc.c  */
-#line 400 "../../../extensions/webalbums/albumtheme.y"
+#line 400 "albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NOT);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -2000,7 +2001,7 @@ yyreduce:
   case 43:
 
 /* Line 1455 of yacc.c  */
-#line 405 "../../../extensions/webalbums/albumtheme.y"
+#line 405 "albumtheme.y"
     { /* function call */
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (4)].text));
@@ -2022,7 +2023,7 @@ yyreduce:
   case 44:
 
 /* Line 1455 of yacc.c  */
-#line 422 "../../../extensions/webalbums/albumtheme.y"
+#line 422 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (1)].text));
@@ -2034,7 +2035,7 @@ yyreduce:
   case 45:
 
 /* Line 1455 of yacc.c  */
-#line 429 "../../../extensions/webalbums/albumtheme.y"
+#line 429 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_string (e, (yyvsp[(2) - (3)].text));
@@ -2046,7 +2047,7 @@ yyreduce:
   case 46:
 
 /* Line 1455 of yacc.c  */
-#line 436 "../../../extensions/webalbums/albumtheme.y"
+#line 436 "albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, (yyvsp[(1) - (1)].ivalue));
@@ -2269,7 +2270,7 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 443 "../../../extensions/webalbums/albumtheme.y"
+#line 443 "albumtheme.y"
 
 
 
